@@ -48,7 +48,7 @@ class Getters(LibraryComponent):
     def get_url(
         self,
         assertion_operator: Optional[AssertionOperator] = None,
-        assertion_expected: Any = None,
+        assertion_expected: Optional[Any] = None,
         message: Optional[str] = None,
     ) -> Any:
         """Returns the current URL.
@@ -78,7 +78,7 @@ class Getters(LibraryComponent):
     def get_page_state(
         self,
         assertion_operator: Optional[AssertionOperator] = None,
-        assertion_expected: Any = None,
+        assertion_expected: Optional[Any] = None,
         message: Optional[str] = None,
     ) -> Any:
         """Returns page model state object as a dictionary.
@@ -115,7 +115,7 @@ class Getters(LibraryComponent):
     def get_page_source(
         self,
         assertion_operator: Optional[AssertionOperator] = None,
-        assertion_expected: Any = None,
+        assertion_expected: Optional[Any] = None,
         message: Optional[str] = None,
     ) -> Any:
         """Gets pages HTML source as a string.
@@ -149,7 +149,7 @@ class Getters(LibraryComponent):
     def get_title(
         self,
         assertion_operator: Optional[AssertionOperator] = None,
-        assertion_expected: Any = None,
+        assertion_expected: Optional[Any] = None,
         message: Optional[str] = None,
     ) -> Any:
         """Returns the title of the current page.
@@ -168,6 +168,7 @@ class Getters(LibraryComponent):
             response = stub.GetTitle(Request().Empty())
             logger.debug(response.log)
             value = response.body
+            logger.info(f"Title: {value!r}")
             formatter = self.keyword_formatters.get(self.get_title)
             return verify_assertion(
                 value,
@@ -184,7 +185,7 @@ class Getters(LibraryComponent):
         self,
         selector: str,
         assertion_operator: Optional[AssertionOperator] = None,
-        assertion_expected: Any = None,
+        assertion_expected: Optional[Any] = None,
         message: Optional[str] = None,
     ) -> Any:
         """Returns text attribute of the element found by ``selector``.
@@ -212,6 +213,7 @@ class Getters(LibraryComponent):
         selector = self.presenter_mode(selector, self.strict_mode)
         response = self._get_text(selector)
         logger.debug(response.log)
+        logger.info(f"Text: {response.body!r}")
         formatter = self.keyword_formatters.get(self.get_text)
         return verify_assertion(
             response.body,
@@ -235,7 +237,7 @@ class Getters(LibraryComponent):
         selector: str,
         property: str,
         assertion_operator: Optional[AssertionOperator] = None,
-        assertion_expected: Any = None,
+        assertion_expected: Optional[Any] = None,
         message: Optional[str] = None,
     ) -> Any:
         """Returns the ``property`` of the element found by ``selector``.
@@ -271,6 +273,7 @@ class Getters(LibraryComponent):
         logger.debug(response.log)
         if response.body:
             value = json.loads(response.body)
+            logger.info(f"Property: {value!r}")
         elif assertion_operator is not None:
             value = None
         else:
@@ -292,7 +295,7 @@ class Getters(LibraryComponent):
         selector: str,
         attribute: str,
         assertion_operator: Optional[AssertionOperator] = None,
-        assertion_expected: Any = None,
+        assertion_expected: Optional[Any] = None,
         message: Optional[str] = None,
     ) -> Any:
         """Returns the HTML ``attribute`` of the element found by ``selector``.
@@ -337,7 +340,7 @@ class Getters(LibraryComponent):
         value = json.loads(response.body)
         if assertion_operator is None and value is None:
             raise AttributeError(f"Attribute '{attribute}' not found!")
-        logger.debug(f"Attribute is: {value}")
+        logger.info(f"Attribute is: {value!r}")
         formatter = self.keyword_formatters.get(self.get_attribute)
         return verify_assertion(
             value,
@@ -373,8 +376,8 @@ class Getters(LibraryComponent):
         is not done.
 
         Available assertions:
-        - ``==`` and ``!=`` can work with multiple values
-        - ``contains`` / ``*=`` only accepts one single expected value
+        - ``==`` , ``!=`` and ``contains`` / ``*=`` can work with multiple values
+        - ``validate`` and ``evaluate`` only accepts one single expected value
 
         Other operators are not allowed.
 
@@ -419,8 +422,8 @@ class Getters(LibraryComponent):
         is not done.
 
         Available assertions:
-        - ``==`` and ``!=`` can work with multiple values
-        - ``contains`` / ``*=`` only accepts one single expected value
+        - ``==`` , ``!=`` and ``contains`` / ``*=`` can work with multiple values
+        - ``validate`` and ``evaluate`` only accepts one single expected value
 
         Other operators are not allowed.
 
@@ -448,7 +451,7 @@ class Getters(LibraryComponent):
         self,
         selector: str,
         assertion_operator: Optional[AssertionOperator] = None,
-        assertion_expected: Any = None,
+        assertion_expected: Optional[Any] = None,
         message: Optional[str] = None,
     ) -> Any:
         """Returns attributes of options of a ``select`` element as a list of dictionaries.
@@ -526,8 +529,8 @@ class Getters(LibraryComponent):
         `Assertions` for further details for the assertion arguments. By default assertion
         is not done.
 
-        - ``==`` and ``!=`` can work with multiple values
-        - ``contains`` / ``*=`` only accepts one single expected value
+        - ``==`` , ``!=`` and ``contains`` / ``*=`` can work with multiple values
+        - ``validate`` and ``evaluate`` only accepts one single expected value
 
         Other operators are not allowed.
 
@@ -665,7 +668,7 @@ class Getters(LibraryComponent):
         self,
         key: SizeFields = SizeFields.ALL,
         assertion_operator: Optional[AssertionOperator] = None,
-        assertion_expected: Any = None,
+        assertion_expected: Optional[Any] = None,
         message: Optional[str] = None,
     ) -> Any:
         """Returns the current viewport dimensions.
@@ -929,10 +932,11 @@ class Getters(LibraryComponent):
     def get_style(
         self,
         selector: str,
-        key: str = "ALL",
+        key: Optional[str] = "ALL",
         assertion_operator: Optional[AssertionOperator] = None,
-        assertion_expected: Any = None,
+        assertion_expected: Optional[Any] = None,
         message: Optional[str] = None,
+        pseudo_element: Optional[str] = None,
     ) -> Any:
         """Gets the computed style properties of the element selected by ``selector``.
 
@@ -941,10 +945,13 @@ class Getters(LibraryComponent):
 
         | =Arguments= | =Description= |
         | ``selector`` | Selector from which the style shall be retrieved. See the `Finding elements` section for details about the selectors. |
-        | ``key`` | Key of the requested CSS property. Retrieves "ALL" styles by default. |
+        | ``key`` | Key of the requested CSS property. Retrieves "ALL" styles as dictionary by default. All css settings can be used as keys even if they are not all returned in the dictionary. |
         | ``assertion_operator`` | See `Assertions` for further details. Defaults to None. |
         | ``assertion_expected`` | Expected value for the counting |
         | ``message`` | overrides the default error message for assertion. |
+        | ``pseudo_element`` | Pseudo element to match. Defaults to None. Pseudo elements are special css |
+
+        [ https://developer.mozilla.org/en-US/docs/Web/CSS/Pseudo-elements | Pseudo element ] is a css fuctionality to add styles. Example `::before` or `::after`.
 
         Keyword uses strict mode, see `Finding elements` for more details about strict mode.
 
@@ -955,30 +962,36 @@ class Getters(LibraryComponent):
         [https://forum.robotframework.org/t//4281|Comment >>]
         """
         selector = self.presenter_mode(selector, self.strict_mode)
+        if key == "ALL" or key is None:
+            key = ""
         with self.playwright.grpc_channel() as stub:
             response = stub.GetStyle(
-                Request().ElementSelector(selector=selector, strict=self.strict_mode)
+                Request().ElementStyle(
+                    selector=selector,
+                    styleKey=key,
+                    pseudo=pseudo_element or "",
+                    strict=self.strict_mode,
+                )
             )
-        parsed = DotDict(json.loads(response.json))
+        parsed_response = json.loads(response.json)
         formatter = self.keyword_formatters.get(self.get_style)
-        if key == "ALL":
+        if key == "" or isinstance(parsed_response, dict):
             if formatter:
                 logger.warn(
                     "Formatter is not supported by Get Style keyword with key 'ALL'."
                 )
             return dict_verify_assertion(
-                parsed,
+                DotDict(parsed_response),
                 assertion_operator,
                 assertion_expected,
                 "Computed style is",
                 message,
             )
         else:
-            item = parsed.get(key, "NOT_FOUND")
             logger.info(f"Value of key: {key}")
-            logger.info(f"Value of selected property: {item}")
+            logger.info(f"Value of selected property: {parsed_response}")
             return verify_assertion(
-                item,
+                parsed_response,
                 assertion_operator,
                 assertion_expected,
                 f"Style value for {key} is",
@@ -993,7 +1006,7 @@ class Getters(LibraryComponent):
         selector: str,
         key: BoundingBoxFields = BoundingBoxFields.ALL,
         assertion_operator: Optional[AssertionOperator] = None,
-        assertion_expected: Any = None,
+        assertion_expected: Optional[Any] = None,
         message: Optional[str] = None,
     ) -> Any:
         """Gets elements size and location as an object ``{x: float, y: float, width: float, height: float}``.
@@ -1053,7 +1066,7 @@ class Getters(LibraryComponent):
         selector: Optional[str] = None,
         key: SizeFields = SizeFields.ALL,
         assertion_operator: Optional[AssertionOperator] = None,
-        assertion_expected: Any = None,
+        assertion_expected: Optional[Any] = None,
         message: Optional[str] = None,
     ) -> Any:
         """Gets elements or pages scrollable size as object ``{width: float, height: float}``.
@@ -1112,7 +1125,7 @@ class Getters(LibraryComponent):
         selector: Optional[str] = None,
         key: AreaFields = AreaFields.ALL,
         assertion_operator: Optional[AssertionOperator] = None,
-        assertion_expected: Any = None,
+        assertion_expected: Optional[Any] = None,
         message: Optional[str] = None,
     ) -> Any:
         """Gets elements or pages current scroll position as object ``{top: float, left: float, bottom: float, right: float}``.
@@ -1171,7 +1184,7 @@ class Getters(LibraryComponent):
         selector: Optional[str] = None,
         key: SizeFields = SizeFields.ALL,
         assertion_operator: Optional[AssertionOperator] = None,
-        assertion_expected: Any = None,
+        assertion_expected: Optional[Any] = None,
         message: Optional[str] = None,
     ) -> Any:
         """Gets elements or pages client size (``clientHeight``, ``clientWidth``) as object {width: float, height: float}.
