@@ -22,20 +22,21 @@
 from typing import Optional
 
 from ..base import LibraryComponent
-from ..utils import is_falsy, keyword, logger
+from ..utils import keyword, logger
+from ..utils.data_types import DelayedKeyword, Scope
 
 
 class RunOnFailureKeywords(LibraryComponent):
     @keyword(tags=("Config",))
     def register_keyword_to_run_on_failure(
-        self, keyword: Optional[str], *args: str
-    ) -> Optional[str]:
+        self, keyword: Optional[str], *args: str, scope: Scope = Scope.Global
+    ) -> DelayedKeyword:
         """Sets the keyword to execute, when a Browser keyword fails.
 
-        ``keyword`` is the name of a keyword that will be executed if a
-        Browser keyword fails. It is possible to use any available
-        keyword, including user keywords or keywords from other libraries.
-        ``args`` are the arguments to the keyword if any.
+        | =Arguments= | =Description= |
+        | ``keyword`` | The name of a keyword that will be executed if a Browser keyword fails. It is possible to use any available keyword, including user keywords or keywords from other libraries. |
+        | ``*args`` | The arguments to the keyword if any. |
+        | ``scope`` | Scope defines the live time of this setting. Available values are ``Global``, ``Suite`` or ``Test`` / ``Task``. See `Scope Settings` for more details. |
 
         The initial keyword to use is set when `importing` the library, and
         the keyword that is used by default is `Take Screenshot`.
@@ -46,23 +47,27 @@ class RunOnFailureKeywords(LibraryComponent):
         case-insensitively, as well as Python ``None`` to disable this
         feature altogether.
 
-        This keyword returns the name of the previously registered
-        failure keyword or Python ``None`` if this functionality was
-        previously disabled. The return value can be always used to
-        restore the original value later.
+        This keyword returns an object which contains the the previously
+        registered failure keyword. The return value can be always used to
+        restore the original value later. The returned object contains
+        keyword name and the possible arguments used to for the keyword.
 
         Example:
         | `Register Keyword To Run On Failure`    Take Screenshot
         | ${previous kw}=    `Register Keyword To Run On Failure`    NONE
         | `Register Keyword To Run On Failure`    ${previous kw}
+        | `Register Keyword To Run On Failure`    Take Screenshot    fullPage=True
+        | `Register Keyword To Run On Failure`    Take Screenshot    failure-{index}    fullPage=True
 
+        [https://forum.robotframework.org/t//4316|Comment >>]
         """
-        old_keyword = self.library.run_on_failure_keyword
-        if keyword is None or is_falsy(keyword):
-            self.library.run_on_failure_keyword = None
+        old_keyword = self.run_on_failure_keyword
+        new_keyword = self.parse_run_on_failure_keyword(
+            f"{keyword}  {'  '.join(args)}".strip()
+        )
+        self.run_on_failure_keyword_stack.set(new_keyword, scope)
+        if new_keyword.name:
+            logger.info(f"'{new_keyword}' will be run on failure.")
         else:
-            self.library.run_on_failure_keyword = {"name": keyword, "args": args}
-        logger.info(f"{keyword or 'No keyword'} will be run on failure.")
-        if old_keyword is None:
-            return None
-        return old_keyword["name"]
+            logger.info("Keyword will not be run on failure.")
+        return old_keyword
